package com.shangyi.quick.service.role.impl;

import cn.dev33.satoken.stp.StpUtil;
import com.shangyi.quick.domain.role.AppRole;
import com.shangyi.quick.domain.role.DoctorAccount;
import com.shangyi.quick.domain.work.WorkGroup;
import com.shangyi.quick.domain.work.WorkGroupRole;
import com.shangyi.quick.mapper.role.AppRoleMapper;
import com.shangyi.quick.mapper.role.DoctorAccountMapper;
import com.shangyi.quick.mapper.work.WorkGroupMapper;
import com.shangyi.quick.service.role.IAppRoleDoctorService;
import com.shangyi.quick.service.role.IAppRoleService;
import com.shangyi.quick.service.role.IDoctorAccountService;
import com.shangyi.quick.service.work.IWorkGroupRoleService;
import com.shangyi.quick.utils.SequeSql;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Date;
import java.util.Iterator;
import java.util.List;
import java.util.Optional;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;
import org.springframework.util.ObjectUtils;
import org.springframework.util.StringUtils;

@Service
public class DoctorAccountServiceImpl implements IDoctorAccountService {
   private static final Logger log = LoggerFactory.getLogger(DoctorAccountServiceImpl.class);
   @Autowired
   DoctorAccountMapper doctorAccountMapper;
   @Autowired
   IAppRoleDoctorService appRoleDoctorService;
   @Autowired
   IAppRoleService appRoleService;
   @Autowired
   AppRoleMapper appRoleMapper;
   @Autowired
   WorkGroupMapper workGroupMapper;
   @Autowired
   IWorkGroupRoleService workGroupRoleService;

   public DoctorAccount selectById(String doctorAccountId, String workId) {
      log.info("根据id查询doctorAccount--->入参: doctorAccountId={},workId={}", doctorAccountId, workId);
      DoctorAccount doctorAccountById = this.doctorAccountMapper.selectById(doctorAccountId);
      List<AppRole> appRoles = this.appRoleService.selectByDoctorId(doctorAccountId, workId);
      doctorAccountById.setAppRoleList(appRoles);
      WorkGroup workGroup = new WorkGroup();
      workGroup.setDoctorAccountId(doctorAccountId);
      List<WorkGroup> workGroupList = this.workGroupMapper.findAll(workGroup);
      doctorAccountById.setWorkId(!ObjectUtils.isEmpty(workGroupList) ? ((WorkGroup)workGroupList.get(0)).getWorkId() : null);
      log.info("根据id查询doctorAccount结果是否为空: {}", ObjectUtils.isEmpty(doctorAccountById));
      return ObjectUtils.isEmpty(doctorAccountById) ? new DoctorAccount() : doctorAccountById;
   }

   public List<DoctorAccount> selectByIds(List<String> doctorAccountIds) {
      log.info("根据多个id查询doctorAccount--->入参: {}", doctorAccountIds);
      List<DoctorAccount> doctorAccountList = this.doctorAccountMapper.selectByIds(doctorAccountIds);
      log.info("根据id查询结果是否为空: {}", CollectionUtils.isEmpty(doctorAccountList));
      Iterator var3 = doctorAccountList.iterator();

      while(var3.hasNext()) {
         DoctorAccount doctorAccount = (DoctorAccount)var3.next();
         WorkGroup workGroup = new WorkGroup();
         workGroup.setDoctorAccountId(doctorAccount.getDoctorAccountId());
         List<WorkGroup> workGroupList = this.workGroupMapper.findAll(workGroup);
         doctorAccount.setWorkId(!ObjectUtils.isEmpty(workGroupList) ? ((WorkGroup)workGroupList.get(0)).getWorkId() : null);
      }

      return (List)(CollectionUtils.isEmpty(doctorAccountList) ? new ArrayList() : doctorAccountList);
   }

   public List<DoctorAccount> findAll(DoctorAccount doctorAccount) {
      log.info("查询所有doctorAccount--->入参: {}", doctorAccount);
      if (!StringUtils.isEmpty(doctorAccount.getRoleIds())) {
         List<String> roleIds = Arrays.asList(doctorAccount.getRoleIds().split(","));
         doctorAccount.setRoleIdList(roleIds);
      }

      String userId = StpUtil.getLoginIdAsString();
      Object user = StpUtil.getSession().get(userId + "_userInfo");
      DoctorAccount da = (DoctorAccount)user;
      doctorAccount.setWorkId(da.getWorkId());
      List<DoctorAccount> doctorAccountList = this.doctorAccountMapper.findAll(doctorAccount);
      log.info("查询所有doctorAccount结果是否为空: {}", CollectionUtils.isEmpty(doctorAccountList));
      return (List)(CollectionUtils.isEmpty(doctorAccountList) ? new ArrayList() : doctorAccountList);
   }

   public int deleteByIds(List<String> doctorAccountIds) {
      log.info("根据多个id删除doctorAccount--->入参: {}", doctorAccountIds);
      int deleteByIds = this.doctorAccountMapper.deleteByIds(doctorAccountIds);
      log.info("根据多个id删除doctorAccount结果: {}", deleteByIds);
      return deleteByIds;
   }

   public List<DoctorAccount> findDoctorHead(String workId) {
      if (ObjectUtils.isEmpty(workId)) {
         String userId = StpUtil.getLoginIdAsString();
         Object user = StpUtil.getSession().get(userId + "_userInfo");
         DoctorAccount da = (DoctorAccount)user;
         workId = da.getWorkId();
      }

      log.info("获取单位={}的医生组长", workId);
      List<DoctorAccount> doctorAccountList = this.doctorAccountMapper.findDoctorHead(workId);
      log.info("获取医生组长结果是否为空: {}", CollectionUtils.isEmpty(doctorAccountList));
      return (List)Optional.ofNullable(doctorAccountList).orElse(new ArrayList());
   }

   public List<DoctorAccount> findDoctorWork() {
      String userId = StpUtil.getLoginIdAsString();
      Object user = StpUtil.getSession().get(userId + "_userInfo");
      DoctorAccount da = (DoctorAccount)user;
      log.info("获取单位={}的医生团队管理", da.getWorkId());
      List<DoctorAccount> doctorAccountList = this.doctorAccountMapper.findDoctorWork(da.getWorkId());
      log.info("获取医生团队管理结果是否为空: {}", CollectionUtils.isEmpty(doctorAccountList));
      return (List)Optional.ofNullable(doctorAccountList).orElse(new ArrayList());
   }

   public int deleteById(String doctorAccountId) {
      log.info("根据id删除doctorAccount--->入参: {}", doctorAccountId);
      int deleteById = this.doctorAccountMapper.deleteById(doctorAccountId);
      log.info("根据id删除doctorAccount结果: {}", deleteById);
      return deleteById;
   }

   public int insertDoctorAccount(DoctorAccount doctorAccount) {
      doctorAccount.setDoctorAccountId(SequeSql.nextId());
      int doctorAccountInsert = this.doctorAccountMapper.insertDoctorAccount(doctorAccount);
      return doctorAccountInsert;
   }

   public int updateStatus(DoctorAccount doctorAccount) {
      int doctorAccountUpdate = this.doctorAccountMapper.updateStatus(doctorAccount);
      return doctorAccountUpdate;
   }

   public int updateDoctorAccount(DoctorAccount doctorAccount) {
      int doctorAccountUpdate = this.doctorAccountMapper.updateDoctorAccount(doctorAccount);
      return doctorAccountUpdate;
   }

   @Transactional(
      rollbackFor = {Exception.class}
   )
   public int save(DoctorAccount doctorAccount) {
      log.info("保存doctorAccount--->入参: {}", doctorAccount);
      String userId = StpUtil.getLoginIdAsString();
      Object user = StpUtil.getSession().get(userId + "_userInfo");
      DoctorAccount da = (DoctorAccount)user;
      String role = this.appRoleMapper.getWorkAdminRole();
      Iterator var6 = doctorAccount.getRoleIdList().iterator();

      while(var6.hasNext()) {
         String roleId = (String)var6.next();
         if (roleId.equals(role)) {
            WorkGroup workGroup = this.workGroupMapper.getWorkAdmin(da.getWorkId());
            if (!ObjectUtils.isEmpty(workGroup) && !workGroup.getDoctorAccountId().equals(doctorAccount.getDoctorAccountId())) {
               log.info("单位已存在管理员，管理员重复--->入参: workId={}", da.getWorkId());
               return -1;
            }
         }
      }

      int updateNum = 0;
      if (ObjectUtils.isEmpty(doctorAccount)) {
         return updateNum;
      } else {
         List<DoctorAccount> accountList = this.doctorAccountMapper.findByMobile1(doctorAccount.getMobile());
         DoctorAccount account = this.doctorAccountMapper.findWork(doctorAccount.getMobile(), da.getWorkId());
         if (!ObjectUtils.isEmpty(account) && StringUtils.isEmpty(doctorAccount.getDoctorAccountId())) {
            log.info("手机号重复，本单位已存在该用户--->入参: workId={}，mobile={}", da.getWorkId(), doctorAccount.getMobile());
            return 2;
         } else {
            List<String> controlRole = null;
            WorkGroup workGroup;
            if (StringUtils.isEmpty(doctorAccount.getDoctorAccountId())) {
               if (ObjectUtils.isEmpty(accountList)) {
                  doctorAccount.setDoctorAccountId(SequeSql.nextId());
                  doctorAccount.setCreateTime(new Date());
                  doctorAccount.setStatus(1);
                  doctorAccount.setCreateBy(StpUtil.getLoginIdAsString());
                  log.info("新增doctorAccount--->参数: {}", doctorAccount);
                  updateNum = this.doctorAccountMapper.insertDoctorAccount(doctorAccount);
               } else {
                  doctorAccount.setDoctorAccountId(((DoctorAccount)accountList.get(0)).getDoctorAccountId());
                  updateNum = 1;
               }
            } else {
               account = this.doctorAccountMapper.selectById(doctorAccount.getDoctorAccountId());
               controlRole = this.appRoleMapper.getControl(da.getWorkId(), doctorAccount.getMobile());
               log.info("修改doctorAccount--->参数: {}", doctorAccount);
               workGroup = new WorkGroup();
               workGroup.setDoctorAccountId(account.getDoctorAccountId());
               workGroup.setWorkId(account.getWorkId());
               List<WorkGroup> workGroupList = this.workGroupMapper.findAll(workGroup);
               if (!ObjectUtils.isEmpty(workGroupList)) {
                  WorkGroupRole workGroupRole = new WorkGroupRole();
                  workGroupRole.setWorkGroupId(((WorkGroup)workGroupList.get(0)).getWorkGroupId());
                  int row = this.workGroupRoleService.delete(workGroupRole);
                  if (row <= 0) {
                     throw new RuntimeException("保存异常");
                  }

                  row = this.workGroupMapper.deleteById(((WorkGroup)workGroupList.get(0)).getWorkGroupId());
                  if (row <= 0) {
                     throw new RuntimeException("保存异常");
                  }
               }

               updateNum = this.doctorAccountMapper.updateDoctorAccount(doctorAccount);
            }

            if (updateNum <= 0) {
               return 0;
            } else {
               workGroup = new WorkGroup();
               workGroup.setWorkGroupId(SequeSql.nextId());
               workGroup.setDoctorAccountId(doctorAccount.getDoctorAccountId());
               workGroup.setWorkId(da.getWorkId());
               log.info("保存doctorAccount，保存团队人员关联--->入参: {}", workGroup);
               int row = this.workGroupMapper.insertWorkGroup(workGroup);
               log.info("保存doctorAccount，保存团队人员关联--->返回: {}", row);
               if (row <= 0) {
                  throw new RuntimeException("异常");
               } else {
                  List<String> roleIdList = doctorAccount.getRoleIdList();
                  if (!CollectionUtils.isEmpty(roleIdList)) {
                     if (!ObjectUtils.isEmpty(controlRole)) {
                        roleIdList.addAll(controlRole);
                     }

                     log.info("开始执行保存医生角色关联: {}", roleIdList);
                     List<WorkGroupRole> workGroupRoles = new ArrayList();
                     roleIdList.forEach((data) -> {
                        WorkGroupRole workGroupRole = new WorkGroupRole();
                        workGroupRole.setWorkGroupRoleId(SequeSql.nextId());
                        workGroupRole.setWorkGroupId(workGroup.getWorkGroupId());
                        workGroupRole.setAppRoleId(data);
                        workGroupRoles.add(workGroupRole);
                     });

                     try {
                        this.workGroupRoleService.saveAll(workGroupRoles);
                     } catch (RuntimeException var15) {
                        RuntimeException e = var15;
                        log.info("开始执行保存医生角色关联: 异常{}", e.getMessage());
                        e.printStackTrace();
                        throw new RuntimeException("异常");
                     }

                     log.info("已执行完毕保存医生角色关联");
                  }

                  log.info("保存doctorAccount结果--->{}", updateNum);
                  return updateNum;
               }
            }
         }
      }
   }
}
